/*      */ package org.apache.batik.swing;
/*      */ 
/*      */ import java.awt.Dimension;
/*      */ import java.awt.EventQueue;
/*      */ import java.awt.event.ActionEvent;
/*      */ import java.awt.event.InputEvent;
/*      */ import java.awt.event.MouseAdapter;
/*      */ import java.awt.event.MouseEvent;
/*      */ import java.awt.event.MouseMotionAdapter;
/*      */ import java.awt.geom.AffineTransform;
/*      */ import java.beans.PropertyChangeListener;
/*      */ import java.beans.PropertyChangeSupport;
/*      */ import java.util.Iterator;
/*      */ import java.util.List;
/*      */ import java.util.Map;
/*      */ import java.util.WeakHashMap;
/*      */ import javax.swing.AbstractAction;
/*      */ import javax.swing.ActionMap;
/*      */ import javax.swing.InputMap;
/*      */ import javax.swing.JDialog;
/*      */ import javax.swing.JOptionPane;
/*      */ import javax.swing.KeyStroke;
/*      */ import javax.swing.ToolTipManager;
/*      */ import org.apache.batik.bridge.UserAgent;
/*      */ import org.apache.batik.css.engine.CSSEngine;
/*      */ import org.apache.batik.css.engine.CSSStylableElement;
/*      */ import org.apache.batik.dom.events.NodeEventTarget;
/*      */ import org.apache.batik.gvt.GraphicsNode;
/*      */ import org.apache.batik.swing.gvt.AbstractImageZoomInteractor;
/*      */ import org.apache.batik.swing.gvt.AbstractJGVTComponent;
/*      */ import org.apache.batik.swing.gvt.AbstractPanInteractor;
/*      */ import org.apache.batik.swing.gvt.AbstractResetTransformInteractor;
/*      */ import org.apache.batik.swing.gvt.AbstractRotateInteractor;
/*      */ import org.apache.batik.swing.gvt.AbstractZoomInteractor;
/*      */ import org.apache.batik.swing.gvt.Interactor;
/*      */ import org.apache.batik.swing.svg.AbstractJSVGComponent;
/*      */ import org.apache.batik.swing.svg.JSVGComponent;
/*      */ import org.apache.batik.swing.svg.SVGDocumentLoaderEvent;
/*      */ import org.apache.batik.swing.svg.SVGUserAgent;
/*      */ import org.apache.batik.util.XMLConstants;
/*      */ import org.apache.batik.util.gui.JErrorPane;
/*      */ import org.w3c.dom.Element;
/*      */ import org.w3c.dom.Node;
/*      */ import org.w3c.dom.events.Event;
/*      */ import org.w3c.dom.events.EventListener;
/*      */ import org.w3c.dom.events.EventTarget;
/*      */ import org.w3c.dom.events.MouseEvent;
/*      */ import org.w3c.dom.svg.SVGDocument;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public class JSVGCanvas
/*      */   extends JSVGComponent
/*      */ {
/*      */   public static final String SCROLL_RIGHT_ACTION = "ScrollRight";
/*      */   public static final String SCROLL_LEFT_ACTION = "ScrollLeft";
/*      */   public static final String SCROLL_UP_ACTION = "ScrollUp";
/*      */   public static final String SCROLL_DOWN_ACTION = "ScrollDown";
/*      */   public static final String FAST_SCROLL_RIGHT_ACTION = "FastScrollRight";
/*      */   public static final String FAST_SCROLL_LEFT_ACTION = "FastScrollLeft";
/*      */   public static final String FAST_SCROLL_UP_ACTION = "FastScrollUp";
/*      */   public static final String FAST_SCROLL_DOWN_ACTION = "FastScrollDown";
/*      */   public static final String ZOOM_IN_ACTION = "ZoomIn";
/*      */   public static final String ZOOM_OUT_ACTION = "ZoomOut";
/*      */   public static final String RESET_TRANSFORM_ACTION = "ResetTransform";
/*      */   private boolean isZoomInteractorEnabled = true;
/*      */   private boolean isImageZoomInteractorEnabled = true;
/*      */   private boolean isPanInteractorEnabled = true;
/*      */   private boolean isRotateInteractorEnabled = true;
/*      */   private boolean isResetTransformInteractorEnabled = true;
/*  178 */   protected PropertyChangeSupport pcs = new PropertyChangeSupport(this);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected String uri;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  189 */   protected LocationListener locationListener = new LocationListener(this);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  195 */   protected Map toolTipMap = null;
/*  196 */   protected EventListener toolTipListener = new ToolTipModifier(this);
/*  197 */   protected EventTarget lastTarget = null;
/*  198 */   protected Map toolTipDocs = null;
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  203 */   protected static final Object MAP_TOKEN = new Object();
/*      */   
/*      */   protected long lastToolTipEventTimeStamp;
/*      */   
/*      */   protected EventTarget lastToolTipEventTarget;
/*      */   
/*      */   protected Interactor zoomInteractor;
/*      */   
/*      */   protected Interactor imageZoomInteractor;
/*      */   
/*      */   protected Interactor panInteractor;
/*      */   
/*      */   protected Interactor rotateInteractor;
/*      */   
/*      */   protected Interactor resetTransformInteractor;
/*      */   
/*      */   public JSVGCanvas() {
/*  220 */     this(null, true, true);
/*  221 */     addMouseMotionListener(this.locationListener);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public JSVGCanvas(SVGUserAgent ua, boolean eventsEnabled, boolean selectableText) {
/*  236 */     super(ua, eventsEnabled, selectableText);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  777 */     this.zoomInteractor = new AbstractZoomInteractor(this) { private final JSVGCanvas this$0;
/*      */         public boolean startInteraction(InputEvent ie) {
/*  779 */           int mods = ie.getModifiers();
/*  780 */           return (ie.getID() == 501 && (mods & 0x10) != 0 && (mods & 0x2) != 0);
/*      */         } }
/*      */       ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  791 */     this.imageZoomInteractor = new AbstractImageZoomInteractor(this) { private final JSVGCanvas this$0;
/*      */         
/*      */         public boolean startInteraction(InputEvent ie) {
/*  794 */           int mods = ie.getModifiers();
/*  795 */           return (ie.getID() == 501 && (mods & 0x4) != 0 && (mods & true) != 0);
/*      */         } }
/*      */       ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  806 */     this.panInteractor = new AbstractPanInteractor(this) { private final JSVGCanvas this$0;
/*      */         public boolean startInteraction(InputEvent ie) {
/*  808 */           int mods = ie.getModifiers();
/*  809 */           return (ie.getID() == 501 && (mods & 0x10) != 0 && (mods & true) != 0);
/*      */         } }
/*      */       ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  820 */     this.rotateInteractor = new AbstractRotateInteractor(this) { private final JSVGCanvas this$0;
/*      */         public boolean startInteraction(InputEvent ie) {
/*  822 */           int mods = ie.getModifiers();
/*  823 */           return (ie.getID() == 501 && (mods & 0x4) != 0 && (mods & 0x2) != 0);
/*      */         } }
/*      */       ;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  834 */     this.resetTransformInteractor = new AbstractResetTransformInteractor(this) { private final JSVGCanvas this$0; private final JSVGCanvas this$0; }; setPreferredSize(new Dimension(200, 200)); setMinimumSize(new Dimension(100, 100)); List intl = getInteractors(); intl.add(this.zoomInteractor); intl.add(this.imageZoomInteractor); intl.add(this.panInteractor); intl.add(this.rotateInteractor); intl.add(this.resetTransformInteractor);
/*      */     installActions();
/*      */     if (eventsEnabled)
/*  837 */     { addMouseListener(new MouseAdapter(this) { public void mousePressed(MouseEvent evt) { this.this$0.requestFocus(); } public boolean startInteraction(InputEvent ie) { int mods = ie.getModifiers();
/*  838 */               return (ie.getID() == 500 && (mods & 0x4) != 0 && (mods & true) != 0 && (mods & 0x2) != 0); } }); installKeyboardActions(); }  addMouseMotionListener(this.locationListener);
/*      */   }
/*      */   protected void installActions() { ActionMap actionMap = getActionMap(); actionMap.put("ScrollRight", new ScrollRightAction(this, 10)); actionMap.put("ScrollLeft", new ScrollLeftAction(this, 10)); actionMap.put("ScrollUp", new ScrollUpAction(this, 10)); actionMap.put("ScrollDown", new ScrollDownAction(this, 10)); actionMap.put("FastScrollRight", new ScrollRightAction(this, 30)); actionMap.put("FastScrollLeft", new ScrollLeftAction(this, 30)); actionMap.put("FastScrollUp", new ScrollUpAction(this, 30)); actionMap.put("FastScrollDown", new ScrollDownAction(this, 30)); actionMap.put("ZoomIn", new ZoomInAction(this)); actionMap.put("ZoomOut", new ZoomOutAction(this)); actionMap.put("ResetTransform", new ResetTransformAction(this)); }
/*      */   public void setDisableInteractions(boolean b) { super.setDisableInteractions(b); ActionMap actionMap = getActionMap(); actionMap.get("ScrollRight").setEnabled(!b); actionMap.get("ScrollLeft").setEnabled(!b); actionMap.get("ScrollUp").setEnabled(!b); actionMap.get("ScrollDown").setEnabled(!b); actionMap.get("FastScrollRight").setEnabled(!b); actionMap.get("FastScrollLeft").setEnabled(!b); actionMap.get("FastScrollUp").setEnabled(!b); actionMap.get("FastScrollDown").setEnabled(!b); actionMap.get("ZoomIn").setEnabled(!b); actionMap.get("ZoomOut").setEnabled(!b); actionMap.get("ResetTransform").setEnabled(!b); }
/*      */   protected void installKeyboardActions() { InputMap inputMap = getInputMap(0); KeyStroke key = KeyStroke.getKeyStroke(39, 0); inputMap.put(key, "ScrollRight"); key = KeyStroke.getKeyStroke(37, 0); inputMap.put(key, "ScrollLeft"); key = KeyStroke.getKeyStroke(38, 0); inputMap.put(key, "ScrollUp"); key = KeyStroke.getKeyStroke(40, 0); inputMap.put(key, "ScrollDown"); key = KeyStroke.getKeyStroke(39, 1); inputMap.put(key, "FastScrollRight"); key = KeyStroke.getKeyStroke(37, 1); inputMap.put(key, "FastScrollLeft"); key = KeyStroke.getKeyStroke(38, 1); inputMap.put(key, "FastScrollUp"); key = KeyStroke.getKeyStroke(40, 1); inputMap.put(key, "FastScrollDown"); key = KeyStroke.getKeyStroke(73, 2); inputMap.put(key, "ZoomIn"); key = KeyStroke.getKeyStroke(79, 2); inputMap.put(key, "ZoomOut"); key = KeyStroke.getKeyStroke(84, 2); inputMap.put(key, "ResetTransform"); } public void addPropertyChangeListener(PropertyChangeListener pcl) { this.pcs.addPropertyChangeListener(pcl); } public void removePropertyChangeListener(PropertyChangeListener pcl) { this.pcs.removePropertyChangeListener(pcl); } public void addPropertyChangeListener(String propertyName, PropertyChangeListener pcl) { this.pcs.addPropertyChangeListener(propertyName, pcl); } public void removePropertyChangeListener(String propertyName, PropertyChangeListener pcl) { this.pcs.removePropertyChangeListener(propertyName, pcl); } public void setEnableZoomInteractor(boolean b) { if (this.isZoomInteractorEnabled != b) { boolean oldValue = this.isZoomInteractorEnabled; this.isZoomInteractorEnabled = b; if (this.isZoomInteractorEnabled) { getInteractors().add(this.zoomInteractor); } else { getInteractors().remove(this.zoomInteractor); }  this.pcs.firePropertyChange("enableZoomInteractor", oldValue, b); }  } public boolean getEnableZoomInteractor() { return this.isZoomInteractorEnabled; } public void setEnableImageZoomInteractor(boolean b) { if (this.isImageZoomInteractorEnabled != b) { boolean oldValue = this.isImageZoomInteractorEnabled; this.isImageZoomInteractorEnabled = b; if (this.isImageZoomInteractorEnabled) { getInteractors().add(this.imageZoomInteractor); } else { getInteractors().remove(this.imageZoomInteractor); }  this.pcs.firePropertyChange("enableImageZoomInteractor", oldValue, b); }  } public boolean getEnableImageZoomInteractor() { return this.isImageZoomInteractorEnabled; } public void setEnablePanInteractor(boolean b) { if (this.isPanInteractorEnabled != b) { boolean oldValue = this.isPanInteractorEnabled; this.isPanInteractorEnabled = b; if (this.isPanInteractorEnabled) { getInteractors().add(this.panInteractor); } else { getInteractors().remove(this.panInteractor); }  this.pcs.firePropertyChange("enablePanInteractor", oldValue, b); }  } public boolean getEnablePanInteractor() { return this.isPanInteractorEnabled; } public void setEnableRotateInteractor(boolean b) { if (this.isRotateInteractorEnabled != b) { boolean oldValue = this.isRotateInteractorEnabled; this.isRotateInteractorEnabled = b; if (this.isRotateInteractorEnabled) { getInteractors().add(this.rotateInteractor); } else { getInteractors().remove(this.rotateInteractor); }  this.pcs.firePropertyChange("enableRotateInteractor", oldValue, b); }  } public boolean getEnableRotateInteractor() { return this.isRotateInteractorEnabled; } public void setEnableResetTransformInteractor(boolean b) { if (this.isResetTransformInteractorEnabled != b) { boolean oldValue = this.isResetTransformInteractorEnabled; this.isResetTransformInteractorEnabled = b; if (this.isResetTransformInteractorEnabled) { getInteractors().add(this.resetTransformInteractor); } else { getInteractors().remove(this.resetTransformInteractor); }  this.pcs.firePropertyChange("enableResetTransformInteractor", oldValue, b); }  } public boolean getEnableResetTransformInteractor() { return this.isResetTransformInteractorEnabled; } public String getURI() { return this.uri; } public void setURI(String newURI) { String oldValue = this.uri; this.uri = newURI; if (this.uri != null) { loadSVGDocument(this.uri); } else { setSVGDocument(null); }  this.pcs.firePropertyChange("URI", oldValue, this.uri); } protected UserAgent createUserAgent() { return new CanvasUserAgent(this); } protected AbstractJGVTComponent.Listener createListener() { return new CanvasSVGListener(this); } protected class CanvasSVGListener extends JSVGComponent.ExtendedSVGListener {
/*      */     private final JSVGCanvas this$0; protected CanvasSVGListener(JSVGCanvas this$0) { super(this$0); this.this$0 = this$0; } public void documentLoadingStarted(SVGDocumentLoaderEvent e) { super.documentLoadingStarted(e); this.this$0.setToolTipText(null); } } protected void installSVGDocument(SVGDocument doc) { if (this.toolTipDocs != null) { Iterator i = this.toolTipDocs.keySet().iterator(); while (i.hasNext()) { SVGDocument ttdoc = (SVGDocument)i.next(); if (ttdoc == null) continue;  NodeEventTarget root = (NodeEventTarget)ttdoc.getRootElement(); if (root == null) continue;  root.removeEventListenerNS("http://www.w3.org/2001/xml-events", "mouseover", this.toolTipListener, false); root.removeEventListenerNS("http://www.w3.org/2001/xml-events", "mouseout", this.toolTipListener, false); }  this.toolTipDocs = null; }  this.lastTarget = null; if (this.toolTipMap != null) this.toolTipMap.clear();  super.installSVGDocument(doc); } public class ResetTransformAction extends AbstractAction {
/*      */     private final JSVGCanvas this$0; public ResetTransformAction(JSVGCanvas this$0) { this.this$0 = this$0; } public void actionPerformed(ActionEvent evt) { this.this$0.fragmentIdentifier = null; this.this$0.resetRenderingTransform(); } } public class AffineAction extends AbstractAction {
/*      */     AffineTransform at; private final JSVGCanvas this$0; public AffineAction(JSVGCanvas this$0, AffineTransform at) { this.this$0 = this$0; this.at = at; } public void actionPerformed(ActionEvent evt) { if (this.this$0.gvtRoot == null) return;  AffineTransform rat = this.this$0.getRenderingTransform(); if (this.at != null) { Dimension dim = this.this$0.getSize(); int x = dim.width / 2; int y = dim.height / 2; AffineTransform t = AffineTransform.getTranslateInstance(x, y); t.concatenate(this.at); t.translate(-x, -y); t.concatenate(rat); this.this$0.setRenderingTransform(t); }  } } public class ZoomAction extends AffineAction {
/*      */     private final JSVGCanvas this$0; public ZoomAction(JSVGCanvas this$0, double scale) { super(this$0, AffineTransform.getScaleInstance(scale, scale)); this.this$0 = this$0; } public ZoomAction(JSVGCanvas this$0, double scaleX, double scaleY) { super(this$0, AffineTransform.getScaleInstance(scaleX, scaleY)); this.this$0 = this$0; } } public class ZoomInAction extends ZoomAction {
/*      */     private final JSVGCanvas this$0; ZoomInAction(JSVGCanvas this$0) { super(this$0, 2.0D); this.this$0 = this$0; } } public class ZoomOutAction extends ZoomAction {
/*      */     private final JSVGCanvas this$0; ZoomOutAction(JSVGCanvas this$0) { super(this$0, 0.5D); this.this$0 = this$0; } } public class RotateAction extends AffineAction {
/*      */     private final JSVGCanvas this$0; public RotateAction(JSVGCanvas this$0, double theta) { super(this$0, AffineTransform.getRotateInstance(theta)); this.this$0 = this$0; } } public class ScrollAction extends AffineAction {
/*      */     private final JSVGCanvas this$0; public ScrollAction(JSVGCanvas this$0, double tx, double ty) { super(this$0, AffineTransform.getTranslateInstance(tx, ty)); this.this$0 = this$0; } } public class ScrollRightAction extends ScrollAction {
/*      */     private final JSVGCanvas this$0; public ScrollRightAction(JSVGCanvas this$0, int inc) { super(this$0, -inc, 0.0D); this.this$0 = this$0; } } public class ScrollLeftAction extends ScrollAction {
/*      */     private final JSVGCanvas this$0; public ScrollLeftAction(JSVGCanvas this$0, int inc) { super(this$0, inc, 0.0D); this.this$0 = this$0; } } public class ScrollUpAction extends ScrollAction {
/*      */     private final JSVGCanvas this$0; public ScrollUpAction(JSVGCanvas this$0, int inc) { super(this$0, 0.0D, inc); this.this$0 = this$0; }
/*      */   } public class ScrollDownAction extends ScrollAction {
/*      */     private final JSVGCanvas this$0; public ScrollDownAction(JSVGCanvas this$0, int inc) { super(this$0, 0.0D, -inc); this.this$0 = this$0; }
/*  856 */   } protected class CanvasUserAgent extends AbstractJSVGComponent.BridgeUserAgent implements XMLConstants { protected CanvasUserAgent(JSVGCanvas this$0) { super(this$0); this.this$0 = this$0;
/*      */ 
/*      */ 
/*      */       
/*  860 */       this.TOOLTIP_TITLE_ONLY = "JSVGCanvas.CanvasUserAgent.ToolTip.titleOnly";
/*      */       
/*  862 */       this.TOOLTIP_DESC_ONLY = "JSVGCanvas.CanvasUserAgent.ToolTip.descOnly";
/*      */       
/*  864 */       this.TOOLTIP_TITLE_AND_TEXT = "JSVGCanvas.CanvasUserAgent.ToolTip.titleAndDesc"; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     final String TOOLTIP_TITLE_ONLY = "JSVGCanvas.CanvasUserAgent.ToolTip.titleOnly";
/*      */ 
/*      */     
/*      */     final String TOOLTIP_DESC_ONLY = "JSVGCanvas.CanvasUserAgent.ToolTip.descOnly";
/*      */ 
/*      */     
/*      */     final String TOOLTIP_TITLE_AND_TEXT = "JSVGCanvas.CanvasUserAgent.ToolTip.titleAndDesc";
/*      */ 
/*      */     
/*      */     private final JSVGCanvas this$0;
/*      */ 
/*      */ 
/*      */     
/*      */     public void handleElement(Element elt, Object data) {
/*      */       String str;
/*      */       Element element;
/*  886 */       super.handleElement(elt, data);
/*      */ 
/*      */       
/*  889 */       if (!this.this$0.isInteractive())
/*      */         return; 
/*  891 */       if (!"http://www.w3.org/2000/svg".equals(elt.getNamespaceURI())) {
/*      */         return;
/*      */       }
/*      */       
/*  895 */       if (elt.getParentNode() == elt.getOwnerDocument().getDocumentElement()) {
/*      */         return;
/*      */       }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/*  903 */       if (data instanceof Element) { element = (Element)data; }
/*  904 */       else { element = (Element)elt.getParentNode(); }
/*      */       
/*  906 */       Element descPeer = null;
/*  907 */       Element titlePeer = null;
/*  908 */       if (elt.getLocalName().equals("title")) {
/*  909 */         if (data == Boolean.TRUE)
/*  910 */           titlePeer = elt; 
/*  911 */         descPeer = getPeerWithTag(element, "http://www.w3.org/2000/svg", "desc");
/*      */       
/*      */       }
/*  914 */       else if (elt.getLocalName().equals("desc")) {
/*  915 */         if (data == Boolean.TRUE)
/*  916 */           descPeer = elt; 
/*  917 */         titlePeer = getPeerWithTag(element, "http://www.w3.org/2000/svg", "title");
/*      */       } 
/*      */ 
/*      */ 
/*      */       
/*  922 */       String titleTip = null;
/*  923 */       if (titlePeer != null) {
/*  924 */         titlePeer.normalize();
/*  925 */         if (titlePeer.getFirstChild() != null) {
/*  926 */           titleTip = titlePeer.getFirstChild().getNodeValue();
/*      */         }
/*      */       } 
/*  929 */       String descTip = null;
/*  930 */       if (descPeer != null) {
/*  931 */         descPeer.normalize();
/*  932 */         if (descPeer.getFirstChild() != null) {
/*  933 */           descTip = descPeer.getFirstChild().getNodeValue();
/*      */         }
/*      */       } 
/*      */       
/*  937 */       if (titleTip != null && titleTip.length() != 0) {
/*  938 */         if (descTip != null && descTip.length() != 0) {
/*  939 */           str = Messages.formatMessage("JSVGCanvas.CanvasUserAgent.ToolTip.titleAndDesc", new Object[] { toFormattedHTML(titleTip), toFormattedHTML(descTip) });
/*      */         
/*      */         }
/*      */         else {
/*      */           
/*  944 */           str = Messages.formatMessage("JSVGCanvas.CanvasUserAgent.ToolTip.titleOnly", new Object[] { toFormattedHTML(titleTip) });
/*      */         
/*      */         }
/*      */       
/*      */       }
/*  949 */       else if (descTip != null && descTip.length() != 0) {
/*  950 */         str = Messages.formatMessage("JSVGCanvas.CanvasUserAgent.ToolTip.descOnly", new Object[] { toFormattedHTML(descTip) });
/*      */       }
/*      */       else {
/*      */         
/*  954 */         str = null;
/*      */       } 
/*      */ 
/*      */       
/*  958 */       if (str == null) {
/*  959 */         removeToolTip(element);
/*      */         
/*      */         return;
/*      */       } 
/*  963 */       if (this.this$0.lastTarget != element) {
/*  964 */         setToolTip(element, str);
/*      */       } else {
/*      */         
/*  967 */         Object o = null;
/*  968 */         if (this.this$0.toolTipMap != null) {
/*  969 */           o = this.this$0.toolTipMap.get(element);
/*  970 */           this.this$0.toolTipMap.put(element, str);
/*      */         } 
/*      */         
/*  973 */         if (o != null) {
/*      */           
/*  975 */           EventQueue.invokeLater(new JSVGCanvas$7(this, str));
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*      */         }
/*      */         else {
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/*  991 */           EventQueue.invokeLater(new JSVGCanvas.ToolTipRunnable(this.this$0, str));
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public String toFormattedHTML(String str) {
/* 1001 */       StringBuffer sb = new StringBuffer(str);
/* 1002 */       replace(sb, '&', "&amp;");
/* 1003 */       replace(sb, '<', "&lt;");
/* 1004 */       replace(sb, '>', "&gt;");
/* 1005 */       replace(sb, '"', "&quot;");
/*      */ 
/*      */ 
/*      */       
/* 1009 */       replace(sb, '\n', "<br>");
/* 1010 */       return sb.toString();
/*      */     }
/*      */     
/*      */     protected void replace(StringBuffer sb, char c, String r) {
/* 1014 */       String v = sb.toString();
/* 1015 */       int i = v.length();
/*      */       
/* 1017 */       while ((i = v.lastIndexOf(c, i - 1)) != -1) {
/* 1018 */         sb.deleteCharAt(i);
/* 1019 */         sb.insert(i, r);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public Element getPeerWithTag(Element parent, String nameSpaceURI, String localName) {
/* 1031 */       Element p = parent;
/* 1032 */       if (p == null) {
/* 1033 */         return null;
/*      */       }
/*      */       
/* 1036 */       for (Node n = p.getFirstChild(); n != null; n = n.getNextSibling()) {
/* 1037 */         if (nameSpaceURI.equals(n.getNamespaceURI()))
/*      */         {
/*      */           
/* 1040 */           if (localName.equals(n.getLocalName()))
/*      */           {
/*      */             
/* 1043 */             if (n.getNodeType() == 1)
/* 1044 */               return (Element)n;  } 
/*      */         }
/*      */       } 
/* 1047 */       return null;
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1058 */     public boolean hasPeerWithTag(Element elt, String nameSpaceURI, String localName) { return (getPeerWithTag(elt, nameSpaceURI, localName) != null); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void setToolTip(Element elt, String toolTip) {
/* 1065 */       if (this.this$0.toolTipMap == null) {
/* 1066 */         this.this$0.toolTipMap = new WeakHashMap();
/*      */       }
/* 1068 */       if (this.this$0.toolTipDocs == null) {
/* 1069 */         this.this$0.toolTipDocs = new WeakHashMap();
/*      */       }
/* 1071 */       SVGDocument doc = (SVGDocument)elt.getOwnerDocument();
/* 1072 */       if (this.this$0.toolTipDocs.put(doc, JSVGCanvas.MAP_TOKEN) == null) {
/*      */         
/* 1074 */         NodeEventTarget root = (NodeEventTarget)doc.getRootElement();
/*      */         
/* 1076 */         root.addEventListenerNS("http://www.w3.org/2001/xml-events", "mouseover", this.this$0.toolTipListener, false, null);
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1081 */         root.addEventListenerNS("http://www.w3.org/2001/xml-events", "mouseout", this.this$0.toolTipListener, false, null);
/*      */       } 
/*      */ 
/*      */ 
/*      */ 
/*      */       
/* 1087 */       this.this$0.toolTipMap.put(elt, toolTip);
/*      */       
/* 1089 */       if (elt == this.this$0.lastTarget)
/* 1090 */         EventQueue.invokeLater(new JSVGCanvas.ToolTipRunnable(this.this$0, toolTip)); 
/*      */     }
/*      */     
/*      */     public void removeToolTip(Element elt) {
/* 1094 */       if (this.this$0.toolTipMap != null)
/* 1095 */         this.this$0.toolTipMap.remove(elt); 
/* 1096 */       if (this.this$0.lastTarget == elt) {
/* 1097 */         EventQueue.invokeLater(new JSVGCanvas.ToolTipRunnable(this.this$0, null));
/*      */       }
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void displayError(String message) {
/* 1105 */       if (this.this$0.svgUserAgent != null) {
/* 1106 */         super.displayError(message);
/*      */       } else {
/* 1108 */         JOptionPane pane = new JOptionPane(message, 0);
/*      */         
/* 1110 */         JDialog dialog = pane.createDialog(this.this$0, "ERROR");
/*      */         
/* 1112 */         dialog.setModal(false);
/* 1113 */         dialog.setVisible(true);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void displayError(Exception ex) {
/* 1121 */       if (this.this$0.svgUserAgent != null) {
/* 1122 */         super.displayError(ex);
/*      */       } else {
/* 1124 */         JErrorPane pane = new JErrorPane(ex, 0);
/*      */         
/* 1126 */         JDialog dialog = pane.createDialog(this.this$0, "ERROR");
/* 1127 */         dialog.setModal(false);
/* 1128 */         dialog.setVisible(true);
/*      */       } 
/*      */     } }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setLastToolTipEvent(long t, EventTarget et) {
/* 1141 */     this.lastToolTipEventTimeStamp = t;
/* 1142 */     this.lastToolTipEventTarget = et;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/* 1150 */   public boolean matchLastToolTipEvent(long t, EventTarget et) { return (this.lastToolTipEventTimeStamp == t && this.lastToolTipEventTarget == et); }
/*      */ 
/*      */   
/*      */   protected class LocationListener
/*      */     extends MouseMotionAdapter
/*      */   {
/*      */     protected int lastX;
/*      */     
/*      */     protected int lastY;
/*      */     private final JSVGCanvas this$0;
/*      */     
/*      */     public LocationListener(JSVGCanvas this$0) {
/* 1162 */       this.this$0 = this$0;
/* 1163 */       this.lastX = 0; this.lastY = 0;
/*      */     }
/*      */     
/*      */     public void mouseMoved(MouseEvent evt) {
/* 1167 */       this.lastX = evt.getX();
/* 1168 */       this.lastY = evt.getY();
/*      */     }
/*      */ 
/*      */     
/* 1172 */     public int getLastX() { return this.lastX; }
/*      */ 
/*      */ 
/*      */     
/* 1176 */     public int getLastY() { return this.lastY; }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected class ToolTipModifier
/*      */     implements EventListener
/*      */   {
/*      */     protected JSVGCanvas.CanvasUserAgent canvasUserAgent;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     private final JSVGCanvas this$0;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1199 */     public ToolTipModifier(JSVGCanvas this$0) { this.this$0 = this$0; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void handleEvent(Event evt) {
/* 1206 */       if (this.this$0.matchLastToolTipEvent(evt.getTimeStamp(), evt.getTarget())) {
/*      */         return;
/*      */       }
/* 1209 */       this.this$0.setLastToolTipEvent(evt.getTimeStamp(), evt.getTarget());
/* 1210 */       EventTarget prevLastTarget = this.this$0.lastTarget;
/* 1211 */       if ("mouseover".equals(evt.getType())) {
/* 1212 */         this.this$0.lastTarget = evt.getTarget();
/* 1213 */       } else if ("mouseout".equals(evt.getType())) {
/*      */ 
/*      */         
/* 1216 */         MouseEvent mouseEvt = (MouseEvent)evt;
/* 1217 */         this.this$0.lastTarget = mouseEvt.getRelatedTarget();
/*      */       } 
/*      */       
/* 1220 */       if (this.this$0.toolTipMap != null) {
/* 1221 */         Element e = (Element)this.this$0.lastTarget;
/* 1222 */         Object o = null;
/* 1223 */         while (e != null) {
/*      */           
/* 1225 */           o = this.this$0.toolTipMap.get(e);
/* 1226 */           if (o != null) {
/*      */             break;
/*      */           }
/* 1229 */           CSSStylableElement cSSStylableElement = CSSEngine.getParentCSSStylableElement(e);
/*      */         } 
/* 1231 */         String theToolTip = (String)o;
/* 1232 */         if (prevLastTarget != this.this$0.lastTarget)
/* 1233 */           EventQueue.invokeLater(new JSVGCanvas.ToolTipRunnable(this.this$0, theToolTip)); 
/*      */       } 
/*      */     } }
/*      */   protected class ToolTipRunnable implements Runnable { String theToolTip;
/*      */     private final JSVGCanvas this$0;
/*      */     
/*      */     public ToolTipRunnable(JSVGCanvas this$0, String toolTip) {
/* 1240 */       this.this$0 = this$0;
/* 1241 */       this.theToolTip = toolTip;
/*      */     }
/*      */     
/*      */     public void run() {
/* 1245 */       this.this$0.setToolTipText(this.theToolTip);
/*      */ 
/*      */       
/* 1248 */       if (this.theToolTip != null) {
/* 1249 */         MouseEvent e = new MouseEvent(this.this$0, 504, System.currentTimeMillis(), 0, this.this$0.locationListener.getLastX(), this.this$0.locationListener.getLastY(), 0, false);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1258 */         ToolTipManager.sharedInstance().mouseEntered(e);
/* 1259 */         e = new MouseEvent(this.this$0, 503, System.currentTimeMillis(), 0, this.this$0.locationListener.getLastX(), this.this$0.locationListener.getLastY(), 0, false);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1268 */         ToolTipManager.sharedInstance().mouseMoved(e);
/*      */       } else {
/* 1270 */         MouseEvent mouseEvent = new MouseEvent(this.this$0, 503, System.currentTimeMillis(), 0, this.this$0.locationListener.getLastX(), this.this$0.locationListener.getLastY(), 0, false);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/* 1279 */         ToolTipManager.sharedInstance().mouseMoved(mouseEvent);
/*      */       } 
/*      */     } }
/*      */ 
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-swing.jar!\org\apache\batik\swing\JSVGCanvas.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */