/*      */ package org.apache.batik.swing.gvt;
/*      */ 
/*      */ import java.awt.AlphaComposite;
/*      */ import java.awt.Color;
/*      */ import java.awt.Dimension;
/*      */ import java.awt.EventQueue;
/*      */ import java.awt.Graphics;
/*      */ import java.awt.Graphics2D;
/*      */ import java.awt.Rectangle;
/*      */ import java.awt.RenderingHints;
/*      */ import java.awt.Shape;
/*      */ import java.awt.event.ComponentAdapter;
/*      */ import java.awt.event.ComponentEvent;
/*      */ import java.awt.event.InputEvent;
/*      */ import java.awt.event.KeyEvent;
/*      */ import java.awt.event.KeyListener;
/*      */ import java.awt.event.MouseEvent;
/*      */ import java.awt.event.MouseListener;
/*      */ import java.awt.event.MouseMotionListener;
/*      */ import java.awt.geom.AffineTransform;
/*      */ import java.awt.geom.NoninvertibleTransformException;
/*      */ import java.awt.image.BufferedImage;
/*      */ import java.text.CharacterIterator;
/*      */ import java.util.Collections;
/*      */ import java.util.Iterator;
/*      */ import java.util.LinkedList;
/*      */ import java.util.List;
/*      */ import javax.swing.JComponent;
/*      */ import org.apache.batik.gvt.GraphicsNode;
/*      */ import org.apache.batik.gvt.event.AWTEventDispatcher;
/*      */ import org.apache.batik.gvt.event.EventDispatcher;
/*      */ import org.apache.batik.gvt.event.SelectionAdapter;
/*      */ import org.apache.batik.gvt.event.SelectionEvent;
/*      */ import org.apache.batik.gvt.renderer.ConcreteImageRendererFactory;
/*      */ import org.apache.batik.gvt.renderer.ImageRenderer;
/*      */ import org.apache.batik.gvt.renderer.ImageRendererFactory;
/*      */ import org.apache.batik.gvt.text.Mark;
/*      */ import org.apache.batik.util.HaltingThread;
/*      */ import org.apache.batik.util.Platform;
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ public abstract class AbstractJGVTComponent
/*      */   extends JComponent
/*      */ {
/*      */   protected Listener listener;
/*      */   protected GVTTreeRenderer gvtTreeRenderer;
/*      */   protected GraphicsNode gvtRoot;
/*      */   protected ImageRendererFactory rendererFactory;
/*      */   protected ImageRenderer renderer;
/*      */   protected List gvtTreeRendererListeners;
/*      */   protected boolean needRender;
/*      */   protected boolean progressivePaint;
/*      */   protected HaltingThread progressivePaintThread;
/*      */   protected BufferedImage image;
/*      */   protected AffineTransform initialTransform;
/*      */   protected AffineTransform renderingTransform;
/*      */   protected AffineTransform paintingTransform;
/*      */   protected List interactors;
/*      */   protected Interactor interactor;
/*      */   protected List overlays;
/*      */   protected List jgvtListeners;
/*      */   protected AWTEventDispatcher eventDispatcher;
/*      */   protected TextSelectionManager textSelectionManager;
/*      */   protected boolean doubleBufferedRendering;
/*      */   protected boolean eventsEnabled;
/*      */   protected boolean selectableText;
/*      */   protected boolean useUnixTextSelection;
/*      */   protected boolean suspendInteractions;
/*      */   protected boolean disableInteractions;
/*      */   
/*  211 */   public AbstractJGVTComponent() { this(false, false); }
/*      */ 
/*      */   
/*      */   public AbstractJGVTComponent(boolean eventsEnabled, boolean selectableText) {
/*      */     this.rendererFactory = new ConcreteImageRendererFactory();
/*      */     this.gvtTreeRendererListeners = Collections.synchronizedList(new LinkedList());
/*      */     this.initialTransform = new AffineTransform();
/*      */     this.renderingTransform = new AffineTransform();
/*      */     this.interactors = new LinkedList();
/*      */     this.overlays = new LinkedList();
/*      */     this.jgvtListeners = null;
/*      */     this.useUnixTextSelection = true;
/*  223 */     setBackground(Color.white);
/*      */ 
/*      */     
/*  226 */     this.eventsEnabled = eventsEnabled;
/*  227 */     this.selectableText = selectableText;
/*      */     
/*  229 */     this.listener = createListener();
/*      */     
/*  231 */     addAWTListeners();
/*      */     
/*  233 */     addGVTTreeRendererListener(this.listener);
/*      */     
/*  235 */     addComponentListener(new ComponentAdapter(this) {
/*      */           public void componentResized(ComponentEvent e) {
/*  237 */             if (this.this$0.updateRenderingTransform()) {
/*  238 */               this.this$0.scheduleGVTRendering();
/*      */             }
/*      */           }
/*      */ 
/*      */           
/*      */           private final AbstractJGVTComponent this$0;
/*      */         });
/*      */   }
/*      */   
/*      */   protected void addAWTListeners() {
/*  248 */     addKeyListener(this.listener);
/*  249 */     addMouseListener(this.listener);
/*  250 */     addMouseMotionListener(this.listener);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  258 */   public void setDisableInteractions(boolean b) { this.disableInteractions = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  266 */   public boolean getDisableInteractions() { return this.disableInteractions; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  277 */   public void setUseUnixTextSelection(boolean b) { this.useUnixTextSelection = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  285 */   public void getUseUnixTextSelection(boolean b) { this.useUnixTextSelection = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  292 */   public List getInteractors() { return this.interactors; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  299 */   public List getOverlays() { return this.overlays; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  306 */   public BufferedImage getOffScreen() { return this.image; }
/*      */ 
/*      */ 
/*      */   
/*      */   public void addJGVTComponentListener(JGVTComponentListener listener) {
/*  311 */     if (this.jgvtListeners == null)
/*  312 */       this.jgvtListeners = new LinkedList(); 
/*  313 */     this.jgvtListeners.add(listener);
/*      */   }
/*      */   
/*      */   public void removeJGVTComponentListener(JGVTComponentListener listener) {
/*  317 */     if (this.jgvtListeners == null)
/*  318 */       return;  this.jgvtListeners.remove(listener);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  325 */   public void resetRenderingTransform() { setRenderingTransform(this.initialTransform); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void stopProcessing() {
/*  332 */     if (this.gvtTreeRenderer != null) {
/*  333 */       this.needRender = false;
/*  334 */       this.gvtTreeRenderer.halt();
/*  335 */       haltProgressivePaintThread();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  343 */   public GraphicsNode getGraphicsNode() { return this.gvtRoot; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setGraphicsNode(GraphicsNode gn) {
/*  350 */     setGraphicsNode(gn, true);
/*  351 */     this.initialTransform = new AffineTransform();
/*  352 */     updateRenderingTransform();
/*  353 */     setRenderingTransform(this.initialTransform, true);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void setGraphicsNode(GraphicsNode gn, boolean createDispatcher) {
/*  360 */     this.gvtRoot = gn;
/*  361 */     if (gn != null && createDispatcher) {
/*  362 */       initializeEventHandling();
/*      */     }
/*  364 */     if (this.eventDispatcher != null) {
/*  365 */       this.eventDispatcher.setRootNode(gn);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void initializeEventHandling() {
/*  373 */     if (this.eventsEnabled) {
/*  374 */       this.eventDispatcher = new AWTEventDispatcher();
/*  375 */       if (this.selectableText) {
/*  376 */         this.textSelectionManager = createTextSelectionManager(this.eventDispatcher);
/*      */         
/*  378 */         this.textSelectionManager.addSelectionListener(new UnixTextSelectionListener(this));
/*      */       } 
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  390 */   protected TextSelectionManager createTextSelectionManager(EventDispatcher ed) { return new TextSelectionManager(this, ed); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  399 */   public TextSelectionManager getTextSelectionManager() { return this.textSelectionManager; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setSelectionOverlayColor(Color color) {
/*  408 */     if (this.textSelectionManager != null) {
/*  409 */       this.textSelectionManager.setSelectionOverlayColor(color);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Color getSelectionOverlayColor() {
/*  417 */     if (this.textSelectionManager != null) {
/*  418 */       return this.textSelectionManager.getSelectionOverlayColor();
/*      */     }
/*  420 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setSelectionOverlayStrokeColor(Color color) {
/*  431 */     if (this.textSelectionManager != null) {
/*  432 */       this.textSelectionManager.setSelectionOverlayStrokeColor(color);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public Color getSelectionOverlayStrokeColor() {
/*  440 */     if (this.textSelectionManager != null) {
/*  441 */       return this.textSelectionManager.getSelectionOverlayStrokeColor();
/*      */     }
/*  443 */     return null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setSelectionOverlayXORMode(boolean state) {
/*  454 */     if (this.textSelectionManager != null) {
/*  455 */       this.textSelectionManager.setSelectionOverlayXORMode(state);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public boolean isSelectionOverlayXORMode() {
/*  464 */     if (this.textSelectionManager != null) {
/*  465 */       return this.textSelectionManager.isSelectionOverlayXORMode();
/*      */     }
/*  467 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void select(Mark start, Mark end) {
/*  478 */     if (this.textSelectionManager != null) {
/*  479 */       this.textSelectionManager.setSelection(start, end);
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void deselectAll() {
/*  487 */     if (this.textSelectionManager != null) {
/*  488 */       this.textSelectionManager.clearSelection();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setProgressivePaint(boolean b) {
/*  500 */     if (this.progressivePaint != b) {
/*  501 */       this.progressivePaint = b;
/*  502 */       haltProgressivePaintThread();
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  510 */   public boolean getProgressivePaint() { return this.progressivePaint; }
/*      */ 
/*      */   
/*      */   public Rectangle getRenderRect() {
/*  514 */     Dimension d = getSize();
/*  515 */     return new Rectangle(0, 0, d.width, d.height);
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void immediateRepaint() {
/*  522 */     if (EventQueue.isDispatchThread()) {
/*  523 */       Rectangle visRect = getRenderRect();
/*  524 */       if (this.doubleBufferedRendering) {
/*  525 */         repaint(visRect.x, visRect.y, visRect.width, visRect.height);
/*      */       } else {
/*      */         
/*  528 */         paintImmediately(visRect.x, visRect.y, visRect.width, visRect.height);
/*      */       } 
/*      */     } else {
/*      */       try {
/*  532 */         EventQueue.invokeAndWait(new Runnable(this) {
/*      */               public void run() {
/*  534 */                 Rectangle visRect = this.this$0.getRenderRect();
/*  535 */                 if (this.this$0.doubleBufferedRendering) {
/*  536 */                   this.this$0.repaint(visRect.x, visRect.y, visRect.width, visRect.height);
/*      */                 } else {
/*      */                   
/*  539 */                   this.this$0.paintImmediately(visRect.x, visRect.y, visRect.width, visRect.height);
/*      */                 } 
/*      */               } private final AbstractJGVTComponent this$0;
/*      */             });
/*  543 */       } catch (Exception e) {}
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void paintComponent(Graphics g) {
/*  552 */     super.paintComponent(g);
/*      */     
/*  554 */     Graphics2D g2d = (Graphics2D)g;
/*      */     
/*  556 */     Rectangle visRect = getRenderRect();
/*  557 */     g2d.setComposite(AlphaComposite.SrcOver);
/*  558 */     g2d.setPaint(getBackground());
/*  559 */     g2d.fillRect(visRect.x, visRect.y, visRect.width, visRect.height);
/*      */ 
/*      */     
/*  562 */     if (this.image != null) {
/*  563 */       if (this.paintingTransform != null) {
/*  564 */         g2d.transform(this.paintingTransform);
/*      */       }
/*  566 */       g2d.drawRenderedImage(this.image, null);
/*  567 */       g2d.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_OFF);
/*      */       
/*  569 */       Iterator it = this.overlays.iterator();
/*  570 */       while (it.hasNext()) {
/*  571 */         ((Overlay)it.next()).paint(g);
/*      */       }
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   public void setPaintingTransform(AffineTransform at) {
/*  582 */     this.paintingTransform = at;
/*  583 */     immediateRepaint();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  590 */   public AffineTransform getPaintingTransform() { return this.paintingTransform; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  598 */   public void setRenderingTransform(AffineTransform at) { setRenderingTransform(at, true); }
/*      */ 
/*      */ 
/*      */   
/*      */   public void setRenderingTransform(AffineTransform at, boolean performRedraw) {
/*  603 */     this.renderingTransform = new AffineTransform(at);
/*  604 */     this.suspendInteractions = true;
/*  605 */     if (this.eventDispatcher != null) {
/*      */       try {
/*  607 */         this.eventDispatcher.setBaseTransform(this.renderingTransform.createInverse());
/*      */       } catch (NoninvertibleTransformException e) {
/*      */         
/*  610 */         handleException(e);
/*      */       } 
/*      */     }
/*  613 */     if (this.jgvtListeners != null) {
/*  614 */       Iterator iter = this.jgvtListeners.iterator();
/*  615 */       ComponentEvent ce = new ComponentEvent(this, 1337);
/*      */       
/*  617 */       while (iter.hasNext()) {
/*  618 */         JGVTComponentListener l = (JGVTComponentListener)iter.next();
/*  619 */         l.componentTransformChanged(ce);
/*      */       } 
/*      */     } 
/*      */     
/*  623 */     if (performRedraw) {
/*  624 */       scheduleGVTRendering();
/*      */     }
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  631 */   public AffineTransform getInitialTransform() { return new AffineTransform(this.initialTransform); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  638 */   public AffineTransform getRenderingTransform() { return new AffineTransform(this.renderingTransform); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  647 */   public void setDoubleBufferedRendering(boolean b) { this.doubleBufferedRendering = b; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  655 */   public boolean getDoubleBufferedRendering() { return this.doubleBufferedRendering; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  662 */   public void addGVTTreeRendererListener(GVTTreeRendererListener l) { this.gvtTreeRendererListeners.add(l); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  669 */   public void removeGVTTreeRendererListener(GVTTreeRendererListener l) { this.gvtTreeRendererListeners.remove(l); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  677 */   public void flush() { this.renderer.flush(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  685 */   public void flush(Rectangle r) { this.renderer.flush(r); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  692 */   protected ImageRenderer createImageRenderer() { return this.rendererFactory.createStaticImageRenderer(); }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void renderGVTTree() {
/*      */     AffineTransform inv;
/*  699 */     Rectangle visRect = getRenderRect();
/*  700 */     if (this.gvtRoot == null || visRect.width <= 0 || visRect.height <= 0) {
/*      */       return;
/*      */     }
/*      */ 
/*      */     
/*  705 */     if (this.renderer == null || this.renderer.getTree() != this.gvtRoot) {
/*  706 */       this.renderer = createImageRenderer();
/*  707 */       this.renderer.setTree(this.gvtRoot);
/*      */     } 
/*      */ 
/*      */ 
/*      */     
/*      */     try {
/*  713 */       inv = this.renderingTransform.createInverse();
/*      */     } catch (NoninvertibleTransformException e) {
/*  715 */       throw new IllegalStateException("NoninvertibleTransformEx:" + e.getMessage());
/*      */     } 
/*  717 */     Shape s = inv.createTransformedShape(visRect);
/*      */ 
/*      */     
/*  720 */     this.gvtTreeRenderer = new GVTTreeRenderer(this.renderer, this.renderingTransform, this.doubleBufferedRendering, s, visRect.width, visRect.height);
/*      */ 
/*      */     
/*  723 */     this.gvtTreeRenderer.setPriority(1);
/*      */     
/*  725 */     Iterator it = this.gvtTreeRendererListeners.iterator();
/*  726 */     while (it.hasNext()) {
/*  727 */       this.gvtTreeRenderer.addGVTTreeRendererListener((GVTTreeRendererListener)it.next());
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  733 */     if (this.eventDispatcher != null) {
/*  734 */       this.eventDispatcher.setEventDispatchEnabled(false);
/*      */     }
/*      */     
/*  737 */     this.gvtTreeRenderer.start();
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected boolean computeRenderingTransform() {
/*  745 */     this.initialTransform = new AffineTransform();
/*  746 */     if (!this.initialTransform.equals(this.renderingTransform)) {
/*  747 */       setRenderingTransform(this.initialTransform, false);
/*  748 */       return true;
/*      */     } 
/*  750 */     return false;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  759 */   protected boolean updateRenderingTransform() { return false; }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void handleException(Exception e) {}
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void releaseRenderingReferences() {
/*  773 */     this.eventDispatcher = null;
/*  774 */     if (this.textSelectionManager != null) {
/*  775 */       this.overlays.remove(this.textSelectionManager.getSelectionOverlay());
/*  776 */       this.textSelectionManager = null;
/*      */     } 
/*  778 */     this.renderer = null;
/*  779 */     this.image = null;
/*  780 */     this.gvtRoot = null;
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*      */   protected void scheduleGVTRendering() {
/*  787 */     if (this.gvtTreeRenderer != null) {
/*  788 */       this.needRender = true;
/*  789 */       this.gvtTreeRenderer.halt();
/*      */     } else {
/*  791 */       renderGVTTree();
/*      */     } 
/*      */   }
/*      */   
/*      */   private void haltProgressivePaintThread() {
/*  796 */     if (this.progressivePaintThread != null) {
/*  797 */       this.progressivePaintThread.halt();
/*  798 */       this.progressivePaintThread = null;
/*      */     } 
/*      */   }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */   
/*  806 */   protected Listener createListener() { return new Listener(this); }
/*      */ 
/*      */   
/*      */   protected class Listener
/*      */     implements GVTTreeRendererListener, KeyListener, MouseListener, MouseMotionListener
/*      */   {
/*      */     boolean checkClick;
/*      */     
/*      */     boolean hadDrag;
/*      */     
/*      */     int startX;
/*      */     
/*      */     int startY;
/*      */     
/*      */     long startTime;
/*      */     long fakeClickTime;
/*      */     int MAX_DISP;
/*      */     long CLICK_TIME;
/*      */     private final AbstractJGVTComponent this$0;
/*      */     
/*      */     protected Listener(AbstractJGVTComponent this$0) {
/*  827 */       this.this$0 = this$0;
/*      */       this.checkClick = false;
/*      */       this.hadDrag = false;
/*      */       this.MAX_DISP = 16;
/*      */       this.CLICK_TIME = 200L;
/*      */     }
/*      */ 
/*      */     
/*      */     public void gvtRenderingPrepare(GVTTreeRendererEvent e) {
/*  836 */       this.this$0.suspendInteractions = true;
/*  837 */       if (!this.this$0.progressivePaint && !this.this$0.doubleBufferedRendering) {
/*  838 */         this.this$0.image = null;
/*      */       }
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void gvtRenderingStarted(GVTTreeRendererEvent e) {
/*  846 */       if (this.this$0.progressivePaint && !this.this$0.doubleBufferedRendering) {
/*  847 */         this.this$0.image = e.getImage();
/*  848 */         this.this$0.progressivePaintThread = new AbstractJGVTComponent$3(this);
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */         
/*  873 */         this.this$0.progressivePaintThread.setPriority(2);
/*  874 */         this.this$0.progressivePaintThread.start();
/*      */       } 
/*  876 */       if (!this.this$0.doubleBufferedRendering) {
/*  877 */         this.this$0.paintingTransform = null;
/*  878 */         this.this$0.suspendInteractions = false;
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void gvtRenderingCompleted(GVTTreeRendererEvent e) {
/*  886 */       this.this$0.haltProgressivePaintThread();
/*      */       
/*  888 */       if (this.this$0.doubleBufferedRendering) {
/*  889 */         this.this$0.paintingTransform = null;
/*  890 */         this.this$0.suspendInteractions = false;
/*      */       } 
/*      */       
/*  893 */       this.this$0.gvtTreeRenderer = null;
/*  894 */       if (this.this$0.needRender) {
/*  895 */         this.this$0.renderGVTTree();
/*  896 */         this.this$0.needRender = false;
/*      */       } else {
/*  898 */         this.this$0.image = e.getImage();
/*  899 */         this.this$0.immediateRepaint();
/*      */       } 
/*  901 */       if (this.this$0.eventDispatcher != null) {
/*  902 */         this.this$0.eventDispatcher.setEventDispatchEnabled(true);
/*      */       }
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  910 */     public void gvtRenderingCancelled(GVTTreeRendererEvent e) { renderingStopped(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  917 */     public void gvtRenderingFailed(GVTTreeRendererEvent e) { renderingStopped(); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     private void renderingStopped() {
/*  925 */       this.this$0.haltProgressivePaintThread();
/*      */       
/*  927 */       if (this.this$0.doubleBufferedRendering) {
/*  928 */         this.this$0.suspendInteractions = false;
/*      */       }
/*      */       
/*  931 */       this.this$0.gvtTreeRenderer = null;
/*  932 */       if (this.this$0.needRender) {
/*  933 */         this.this$0.renderGVTTree();
/*  934 */         this.this$0.needRender = false;
/*      */       } else {
/*  936 */         this.this$0.immediateRepaint();
/*      */       } 
/*      */       
/*  939 */       if (this.this$0.eventDispatcher != null) {
/*  940 */         this.this$0.eventDispatcher.setEventDispatchEnabled(true);
/*      */       }
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void keyTyped(KeyEvent e) {
/*  951 */       selectInteractor(e);
/*  952 */       if (this.this$0.interactor != null) {
/*  953 */         this.this$0.interactor.keyTyped(e);
/*  954 */         deselectInteractor();
/*  955 */       } else if (this.this$0.eventDispatcher != null) {
/*  956 */         dispatchKeyTyped(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  964 */     protected void dispatchKeyTyped(KeyEvent e) { this.this$0.eventDispatcher.keyTyped(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void keyPressed(KeyEvent e) {
/*  971 */       selectInteractor(e);
/*  972 */       if (this.this$0.interactor != null) {
/*  973 */         this.this$0.interactor.keyPressed(e);
/*  974 */         deselectInteractor();
/*  975 */       } else if (this.this$0.eventDispatcher != null) {
/*  976 */         dispatchKeyPressed(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*  984 */     protected void dispatchKeyPressed(KeyEvent e) { this.this$0.eventDispatcher.keyPressed(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void keyReleased(KeyEvent e) {
/*  991 */       selectInteractor(e);
/*  992 */       if (this.this$0.interactor != null) {
/*  993 */         this.this$0.interactor.keyReleased(e);
/*  994 */         deselectInteractor();
/*  995 */       } else if (this.this$0.eventDispatcher != null) {
/*  996 */         dispatchKeyReleased(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1004 */     protected void dispatchKeyReleased(KeyEvent e) { this.this$0.eventDispatcher.keyReleased(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mouseClicked(MouseEvent e) {
/* 1015 */       if (this.fakeClickTime != e.getWhen())
/* 1016 */         handleMouseClicked(e); 
/*      */     }
/*      */     
/*      */     public void handleMouseClicked(MouseEvent e) {
/* 1020 */       selectInteractor(e);
/* 1021 */       if (this.this$0.interactor != null) {
/* 1022 */         this.this$0.interactor.mouseClicked(e);
/* 1023 */         deselectInteractor();
/* 1024 */       } else if (this.this$0.eventDispatcher != null) {
/* 1025 */         dispatchMouseClicked(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1033 */     protected void dispatchMouseClicked(MouseEvent e) { this.this$0.eventDispatcher.mouseClicked(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mousePressed(MouseEvent e) {
/* 1040 */       this.startX = e.getX();
/* 1041 */       this.startY = e.getY();
/* 1042 */       this.startTime = e.getWhen();
/*      */       
/* 1044 */       this.checkClick = true;
/*      */       
/* 1046 */       selectInteractor(e);
/* 1047 */       if (this.this$0.interactor != null) {
/* 1048 */         this.this$0.interactor.mousePressed(e);
/* 1049 */         deselectInteractor();
/* 1050 */       } else if (this.this$0.eventDispatcher != null) {
/* 1051 */         dispatchMousePressed(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1059 */     protected void dispatchMousePressed(MouseEvent e) { this.this$0.eventDispatcher.mousePressed(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mouseReleased(MouseEvent e) {
/* 1066 */       if (this.checkClick && this.hadDrag) {
/* 1067 */         int dx = this.startX - e.getX();
/* 1068 */         int dy = this.startY - e.getY();
/* 1069 */         long cTime = e.getWhen();
/* 1070 */         if (dx * dx + dy * dy < this.MAX_DISP && cTime - this.startTime < this.CLICK_TIME) {
/*      */ 
/*      */ 
/*      */           
/* 1074 */           MouseEvent click = new MouseEvent(e.getComponent(), 500, e.getWhen(), e.getModifiers(), e.getX(), e.getY(), e.getClickCount(), e.isPopupTrigger());
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */           
/* 1084 */           this.fakeClickTime = click.getWhen();
/* 1085 */           handleMouseClicked(click);
/*      */         } 
/*      */       } 
/* 1088 */       this.checkClick = false;
/* 1089 */       this.hadDrag = false;
/*      */       
/* 1091 */       selectInteractor(e);
/* 1092 */       if (this.this$0.interactor != null) {
/* 1093 */         this.this$0.interactor.mouseReleased(e);
/* 1094 */         deselectInteractor();
/* 1095 */       } else if (this.this$0.eventDispatcher != null) {
/* 1096 */         dispatchMouseReleased(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1104 */     protected void dispatchMouseReleased(MouseEvent e) { this.this$0.eventDispatcher.mouseReleased(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mouseEntered(MouseEvent e) {
/* 1112 */       selectInteractor(e);
/* 1113 */       if (this.this$0.interactor != null) {
/* 1114 */         this.this$0.interactor.mouseEntered(e);
/* 1115 */         deselectInteractor();
/* 1116 */       } else if (this.this$0.eventDispatcher != null) {
/* 1117 */         dispatchMouseEntered(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1125 */     protected void dispatchMouseEntered(MouseEvent e) { this.this$0.eventDispatcher.mouseEntered(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mouseExited(MouseEvent e) {
/* 1132 */       selectInteractor(e);
/* 1133 */       if (this.this$0.interactor != null) {
/* 1134 */         this.this$0.interactor.mouseExited(e);
/* 1135 */         deselectInteractor();
/* 1136 */       } else if (this.this$0.eventDispatcher != null) {
/* 1137 */         dispatchMouseExited(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1145 */     protected void dispatchMouseExited(MouseEvent e) { this.this$0.eventDispatcher.mouseExited(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mouseDragged(MouseEvent e) {
/* 1158 */       this.hadDrag = true;
/* 1159 */       int dx = this.startX - e.getX();
/* 1160 */       int dy = this.startY - e.getY();
/* 1161 */       if (dx * dx + dy * dy > this.MAX_DISP) {
/* 1162 */         this.checkClick = false;
/*      */       }
/* 1164 */       selectInteractor(e);
/* 1165 */       if (this.this$0.interactor != null) {
/* 1166 */         this.this$0.interactor.mouseDragged(e);
/* 1167 */         deselectInteractor();
/* 1168 */       } else if (this.this$0.eventDispatcher != null) {
/* 1169 */         dispatchMouseDragged(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1177 */     protected void dispatchMouseDragged(MouseEvent e) { this.this$0.eventDispatcher.mouseDragged(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     public void mouseMoved(MouseEvent e) {
/* 1185 */       selectInteractor(e);
/* 1186 */       if (this.this$0.interactor != null) {
/*      */         
/* 1188 */         if (Platform.isOSX && this.this$0.interactor instanceof AbstractZoomInteractor) {
/*      */           
/* 1190 */           mouseDragged(e);
/*      */         } else {
/* 1192 */           this.this$0.interactor.mouseMoved(e);
/* 1193 */         }  deselectInteractor();
/* 1194 */       } else if (this.this$0.eventDispatcher != null) {
/* 1195 */         dispatchMouseMoved(e);
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/* 1203 */     protected void dispatchMouseMoved(MouseEvent e) { this.this$0.eventDispatcher.mouseMoved(e); }
/*      */ 
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected void selectInteractor(InputEvent ie) {
/* 1210 */       if (!this.this$0.disableInteractions && !this.this$0.suspendInteractions && this.this$0.interactor == null && this.this$0.gvtRoot != null) {
/*      */ 
/*      */ 
/*      */         
/* 1214 */         Iterator it = this.this$0.interactors.iterator();
/* 1215 */         while (it.hasNext()) {
/* 1216 */           Interactor i = (Interactor)it.next();
/* 1217 */           if (i.startInteraction(ie)) {
/* 1218 */             this.this$0.interactor = i;
/*      */             break;
/*      */           } 
/*      */         } 
/*      */       } 
/*      */     }
/*      */ 
/*      */ 
/*      */ 
/*      */     
/*      */     protected void deselectInteractor() {
/* 1229 */       if (this.this$0.interactor.endInteraction())
/* 1230 */         this.this$0.interactor = null; 
/*      */     } }
/*      */   
/*      */   protected class UnixTextSelectionListener extends SelectionAdapter { private final AbstractJGVTComponent this$0;
/*      */     
/* 1235 */     protected UnixTextSelectionListener(AbstractJGVTComponent this$0) { this.this$0 = this$0; }
/*      */ 
/*      */     
/*      */     public void selectionDone(SelectionEvent evt) {
/* 1239 */       if (!this.this$0.useUnixTextSelection)
/*      */         return; 
/* 1241 */       Object o = evt.getSelection();
/* 1242 */       if (!(o instanceof CharacterIterator))
/*      */         return; 
/* 1244 */       CharacterIterator iter = (CharacterIterator)o;
/*      */ 
/*      */ 
/*      */       
/* 1248 */       SecurityManager securityManager = System.getSecurityManager();
/* 1249 */       if (securityManager != null) {
/*      */         try {
/* 1251 */           securityManager.checkSystemClipboardAccess();
/*      */         }
/* 1253 */         catch (SecurityException e) {
/*      */           return;
/*      */         } 
/*      */       }
/* 1257 */       int sz = iter.getEndIndex() - iter.getBeginIndex();
/* 1258 */       if (sz == 0)
/*      */         return; 
/* 1260 */       char[] cbuff = new char[sz];
/* 1261 */       cbuff[0] = iter.first();
/* 1262 */       for (int i = 1; i < cbuff.length; i++) {
/* 1263 */         cbuff[i] = iter.next();
/*      */       }
/* 1265 */       String strSel = new String(cbuff);
/*      */ 
/*      */ 
/*      */       
/* 1269 */       (new AbstractJGVTComponent$5(this, strSel)).start();
/*      */     } }
/*      */ 
/*      */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-swing.jar!\org\apache\batik\swing\gvt\AbstractJGVTComponent.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */