/*     */ package org.apache.batik.swing.gvt;
/*     */ 
/*     */ import java.awt.BasicStroke;
/*     */ import java.awt.Color;
/*     */ import java.awt.Cursor;
/*     */ import java.awt.Graphics;
/*     */ import java.awt.Graphics2D;
/*     */ import java.awt.Rectangle;
/*     */ import java.awt.Shape;
/*     */ import java.awt.geom.AffineTransform;
/*     */ import org.apache.batik.gvt.event.EventDispatcher;
/*     */ import org.apache.batik.gvt.event.GraphicsNodeMouseEvent;
/*     */ import org.apache.batik.gvt.event.GraphicsNodeMouseListener;
/*     */ import org.apache.batik.gvt.event.SelectionEvent;
/*     */ import org.apache.batik.gvt.event.SelectionListener;
/*     */ import org.apache.batik.gvt.text.ConcreteTextSelector;
/*     */ import org.apache.batik.gvt.text.Mark;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class TextSelectionManager
/*     */ {
/*  51 */   public static final Cursor TEXT_CURSOR = new Cursor(2);
/*     */   
/*     */   protected ConcreteTextSelector textSelector;
/*     */   protected AbstractJGVTComponent component;
/*     */   protected Overlay selectionOverlay;
/*     */   protected MouseListener mouseListener;
/*     */   protected Cursor previousCursor;
/*     */   protected Shape selectionHighlight;
/*     */   protected SelectionListener textSelectionListener;
/*     */   protected Color selectionOverlayColor;
/*     */   protected Color selectionOverlayStrokeColor;
/*     */   protected boolean xorMode;
/*     */   Object selection;
/*     */   
/*     */   public TextSelectionManager(AbstractJGVTComponent comp, EventDispatcher ed) {
/*  66 */     this.selectionOverlay = new SelectionOverlay(this);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  91 */     this.selectionOverlayColor = new Color(100, 100, 255, 100);
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  96 */     this.selectionOverlayStrokeColor = Color.white;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 102 */     this.xorMode = false;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 107 */     this.selection = null;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 114 */     this.textSelector = new ConcreteTextSelector();
/* 115 */     this.textSelectionListener = new TextSelectionListener(this);
/* 116 */     this.textSelector.addSelectionListener(this.textSelectionListener);
/* 117 */     this.mouseListener = new MouseListener(this);
/*     */     
/* 119 */     this.component = comp;
/* 120 */     this.component.getOverlays().add(this.selectionOverlay);
/*     */     
/* 122 */     ed.addGraphicsNodeMouseListener(this.mouseListener);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 130 */   public void addSelectionListener(SelectionListener sl) { this.textSelector.addSelectionListener(sl); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 138 */   public void removeSelectionListener(SelectionListener sl) { this.textSelector.removeSelectionListener(sl); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 147 */   public void setSelectionOverlayColor(Color color) { this.selectionOverlayColor = color; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 154 */   public Color getSelectionOverlayColor() { return this.selectionOverlayColor; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 164 */   public void setSelectionOverlayStrokeColor(Color color) { this.selectionOverlayStrokeColor = color; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 171 */   public Color getSelectionOverlayStrokeColor() { return this.selectionOverlayStrokeColor; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 181 */   public void setSelectionOverlayXORMode(boolean state) { this.xorMode = state; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 189 */   public boolean isSelectionOverlayXORMode() { return this.xorMode; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 196 */   public Overlay getSelectionOverlay() { return this.selectionOverlay; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 203 */   public Object getSelection() { return this.selection; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 210 */   public void setSelection(Mark start, Mark end) { this.textSelector.setSelection(start, end); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 217 */   public void clearSelection() { this.textSelector.clearSelection(); }
/*     */   
/*     */   protected class MouseListener
/*     */     implements GraphicsNodeMouseListener {
/*     */     private final TextSelectionManager this$0;
/*     */     
/* 223 */     protected MouseListener(TextSelectionManager this$0) { this.this$0 = this$0; }
/*     */     public void mouseClicked(GraphicsNodeMouseEvent evt) {
/* 225 */       if (evt.getSource() instanceof org.apache.batik.gvt.Selectable) {
/* 226 */         this.this$0.textSelector.mouseClicked(evt);
/*     */       }
/*     */     }
/*     */     
/*     */     public void mousePressed(GraphicsNodeMouseEvent evt) {
/* 231 */       if (evt.getSource() instanceof org.apache.batik.gvt.Selectable) {
/* 232 */         this.this$0.textSelector.mousePressed(evt);
/* 233 */       } else if (this.this$0.selectionHighlight != null) {
/* 234 */         this.this$0.textSelector.clearSelection();
/*     */       } 
/*     */     }
/*     */ 
/*     */     
/* 239 */     public void mouseReleased(GraphicsNodeMouseEvent evt) { this.this$0.textSelector.mouseReleased(evt); }
/*     */ 
/*     */     
/*     */     public void mouseEntered(GraphicsNodeMouseEvent evt) {
/* 243 */       if (evt.getSource() instanceof org.apache.batik.gvt.Selectable) {
/* 244 */         this.this$0.textSelector.mouseEntered(evt);
/* 245 */         this.this$0.previousCursor = this.this$0.component.getCursor();
/* 246 */         if (this.this$0.previousCursor.getType() == 0) {
/* 247 */           this.this$0.component.setCursor(TextSelectionManager.TEXT_CURSOR);
/*     */         }
/*     */       } 
/*     */     }
/*     */     
/*     */     public void mouseExited(GraphicsNodeMouseEvent evt) {
/* 253 */       if (evt.getSource() instanceof org.apache.batik.gvt.Selectable) {
/* 254 */         this.this$0.textSelector.mouseExited(evt);
/* 255 */         if (this.this$0.component.getCursor() == TextSelectionManager.TEXT_CURSOR) {
/* 256 */           this.this$0.component.setCursor(this.this$0.previousCursor);
/*     */         }
/*     */       } 
/*     */     }
/*     */     
/*     */     public void mouseDragged(GraphicsNodeMouseEvent evt) {
/* 262 */       if (evt.getSource() instanceof org.apache.batik.gvt.Selectable)
/* 263 */         this.this$0.textSelector.mouseDragged(evt); 
/*     */     }
/*     */     
/*     */     public void mouseMoved(GraphicsNodeMouseEvent evt) {}
/*     */   }
/*     */   
/*     */   protected class TextSelectionListener
/*     */     implements SelectionListener {
/*     */     private final TextSelectionManager this$0;
/*     */     
/* 273 */     protected TextSelectionListener(TextSelectionManager this$0) { this.this$0 = this$0; }
/*     */     public void selectionDone(SelectionEvent e) {
/* 275 */       selectionChanged(e);
/* 276 */       this.this$0.selection = e.getSelection();
/*     */     }
/*     */     
/* 279 */     public void selectionCleared(SelectionEvent e) { selectionStarted(e); }
/*     */     
/*     */     public void selectionStarted(SelectionEvent e) {
/* 282 */       if (this.this$0.selectionHighlight != null) {
/* 283 */         Rectangle r = this.this$0.getHighlightBounds();
/* 284 */         this.this$0.selectionHighlight = null;
/* 285 */         this.this$0.component.repaint(r);
/*     */       } 
/* 287 */       this.this$0.selection = null;
/*     */     }
/*     */     public void selectionChanged(SelectionEvent e) {
/* 290 */       Rectangle r = null;
/* 291 */       AffineTransform at = this.this$0.component.getRenderingTransform();
/* 292 */       if (this.this$0.selectionHighlight != null) {
/* 293 */         r = at.createTransformedShape(this.this$0.selectionHighlight).getBounds();
/* 294 */         this.this$0.outset(r, 1);
/*     */       } 
/*     */       
/* 297 */       this.this$0.selectionHighlight = e.getHighlightShape();
/* 298 */       if (this.this$0.selectionHighlight != null) {
/* 299 */         if (r != null) {
/* 300 */           Rectangle r2 = this.this$0.getHighlightBounds();
/* 301 */           r2.add(r);
/* 302 */           this.this$0.component.repaint(r2);
/*     */         } else {
/* 304 */           this.this$0.component.repaint(this.this$0.getHighlightBounds());
/*     */         } 
/* 306 */       } else if (r != null) {
/* 307 */         this.this$0.component.repaint(r);
/*     */       } 
/*     */     }
/*     */   }
/*     */ 
/*     */   
/*     */   protected Rectangle outset(Rectangle r, int amount) {
/* 314 */     r.x -= amount;
/* 315 */     r.y -= amount;
/* 316 */     r.width += 2 * amount;
/* 317 */     r.height += 2 * amount;
/* 318 */     return r;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Rectangle getHighlightBounds() {
/* 325 */     AffineTransform at = this.component.getRenderingTransform();
/* 326 */     Shape s = at.createTransformedShape(this.selectionHighlight);
/* 327 */     return outset(s.getBounds(), 1);
/*     */   }
/*     */   
/*     */   protected class SelectionOverlay implements Overlay {
/*     */     private final TextSelectionManager this$0;
/*     */     
/* 333 */     protected SelectionOverlay(TextSelectionManager this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public void paint(Graphics g) {
/* 339 */       if (this.this$0.selectionHighlight != null) {
/* 340 */         AffineTransform at = this.this$0.component.getRenderingTransform();
/* 341 */         Shape s = at.createTransformedShape(this.this$0.selectionHighlight);
/*     */         
/* 343 */         Graphics2D g2d = (Graphics2D)g;
/* 344 */         if (this.this$0.xorMode) {
/* 345 */           g2d.setColor(Color.black);
/* 346 */           g2d.setXORMode(Color.white);
/* 347 */           g2d.fill(s);
/*     */         } else {
/* 349 */           g2d.setColor(this.this$0.selectionOverlayColor);
/* 350 */           g2d.fill(s);
/* 351 */           if (this.this$0.selectionOverlayStrokeColor != null) {
/* 352 */             g2d.setStroke(new BasicStroke(1.0F));
/* 353 */             g2d.setColor(this.this$0.selectionOverlayStrokeColor);
/* 354 */             g2d.draw(s);
/*     */           } 
/*     */         } 
/*     */       } 
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-swing.jar!\org\apache\batik\swing\gvt\TextSelectionManager.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */