/*     */ package org.apache.batik.swing.svg;
/*     */ 
/*     */ import java.io.InterruptedIOException;
/*     */ import java.util.Collections;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import org.apache.batik.bridge.DocumentLoader;
/*     */ import org.apache.batik.util.EventDispatcher;
/*     */ import org.apache.batik.util.HaltingThread;
/*     */ import org.w3c.dom.svg.SVGDocument;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class SVGDocumentLoader
/*     */   extends HaltingThread
/*     */ {
/*     */   protected String url;
/*     */   protected DocumentLoader loader;
/*     */   protected Exception exception;
/*     */   protected List listeners;
/*     */   
/*     */   public SVGDocumentLoader(String u, DocumentLoader l) {
/*  59 */     this.listeners = Collections.synchronizedList(new LinkedList());
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*  67 */     this.url = u;
/*  68 */     this.loader = l;
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void run() {
/*  76 */     SVGDocumentLoaderEvent evt = new SVGDocumentLoaderEvent(this, null);
/*     */     try {
/*  78 */       fireEvent(startedDispatcher, evt);
/*  79 */       if (isHalted()) {
/*  80 */         fireEvent(cancelledDispatcher, evt);
/*     */         
/*     */         return;
/*     */       } 
/*  84 */       SVGDocument svgDocument = (SVGDocument)this.loader.loadDocument(this.url);
/*     */       
/*  86 */       if (isHalted()) {
/*  87 */         fireEvent(cancelledDispatcher, evt);
/*     */         
/*     */         return;
/*     */       } 
/*  91 */       evt = new SVGDocumentLoaderEvent(this, svgDocument);
/*  92 */       fireEvent(completedDispatcher, evt);
/*     */     } catch (InterruptedIOException e) {
/*  94 */       fireEvent(cancelledDispatcher, evt);
/*     */     } catch (Exception e) {
/*  96 */       this.exception = e = null;
/*  97 */       fireEvent(failedDispatcher, evt);
/*     */     } catch (ThreadDeath td) {
/*  99 */       this.exception = new Exception(td.getMessage());
/* 100 */       fireEvent(failedDispatcher, evt);
/* 101 */       throw td;
/*     */     } catch (Throwable t) {
/* 103 */       t.printStackTrace();
/* 104 */       this.exception = new Exception(t.getMessage());
/* 105 */       fireEvent(failedDispatcher, evt);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 113 */   public Exception getException() { return this.exception; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 120 */   public void addSVGDocumentLoaderListener(SVGDocumentLoaderListener l) { this.listeners.add(l); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 127 */   public void removeSVGDocumentLoaderListener(SVGDocumentLoaderListener l) { this.listeners.remove(l); }
/*     */ 
/*     */ 
/*     */   
/* 131 */   public void fireEvent(EventDispatcher.Dispatcher dispatcher, Object event) { EventDispatcher.fireEvent(dispatcher, this.listeners, event, true); }
/*     */ 
/*     */   
/* 134 */   static EventDispatcher.Dispatcher startedDispatcher = new EventDispatcher.Dispatcher()
/*     */     {
/*     */       public void dispatch(Object listener, Object event) {
/* 137 */         ((SVGDocumentLoaderListener)listener).documentLoadingStarted((SVGDocumentLoaderEvent)event);
/*     */       }
/*     */     };
/*     */ 
/*     */   
/* 142 */   static EventDispatcher.Dispatcher completedDispatcher = new EventDispatcher.Dispatcher()
/*     */     {
/*     */       public void dispatch(Object listener, Object event) {
/* 145 */         ((SVGDocumentLoaderListener)listener).documentLoadingCompleted((SVGDocumentLoaderEvent)event);
/*     */       }
/*     */     };
/*     */ 
/*     */   
/* 150 */   static EventDispatcher.Dispatcher cancelledDispatcher = new EventDispatcher.Dispatcher()
/*     */     {
/*     */       public void dispatch(Object listener, Object event) {
/* 153 */         ((SVGDocumentLoaderListener)listener).documentLoadingCancelled((SVGDocumentLoaderEvent)event);
/*     */       }
/*     */     };
/*     */ 
/*     */   
/* 158 */   static EventDispatcher.Dispatcher failedDispatcher = new EventDispatcher.Dispatcher()
/*     */     {
/*     */       public void dispatch(Object listener, Object event) {
/* 161 */         ((SVGDocumentLoaderListener)listener).documentLoadingFailed((SVGDocumentLoaderEvent)event);
/*     */       }
/*     */     };
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-swing.jar!\org\apache\batik\swing\svg\SVGDocumentLoader.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */